<?php
/**
 * Perforce Swarm
 *
 * @copyright   2013-2020 Perforce Software. All rights reserved.
 * @license     Please see LICENSE.txt in top-level readme folder of this distribution.
 * @version     2019.3/2027974
 */
namespace TestIntegration\Filter;

use Zend\Validator\AbstractValidator;

/**
 * Class EncodingValidator to validate the encoding on a test definition
 * @package TestIntegration\Filter
 */
class EncodingValidator extends AbstractValidator
{
    const ENCODINGS        = ['json', 'url'];
    const INVALID_ENCODING = 'invalidEncoding';

    private $translator;

    /**
     * EncodingValidator constructor.
     * @param mixed     $translator     to translate messages
     */
    public function __construct($translator)
    {
        parent::__construct();
        $this->translator = $translator;
    }

    /**
     * Validate the encoding
     * @param mixed $value  value to validate
     * @return bool true if valid
     */
    public function isValid($value)
    {
        if (!in_array(strtolower($value), self::ENCODINGS)) {
            $this->abstractOptions['messages'][self::INVALID_ENCODING] =
                $this->translator->t(
                    "Invalid encoding [%s], must be one of [%s]",
                    [$value, implode(', ', self::ENCODINGS)]
                );
            return false;
        }
        return true;
    }
}
