<?php
/**
 * Perforce Swarm
 *
 * @copyright   2013-2020 Perforce Software. All rights reserved.
 * @license     Please see LICENSE.txt in top-level readme folder of this distribution.
 * @version     2019.3/2027974
 */

use Application\Factory\InvokableServiceFactory;
use Application\Model\IModelDAO;
use Workflow\Model\IWorkflow;
use Workflow\Controller\IndexController;
use Application\Controller\IndexControllerFactory;
use Redis\Model\WorkflowDAO;
use Workflow\Manager;
use Application\Config\Services;

return [
    IWorkflow::WORKFLOW => [
        IWorkflow::WORKFLOW_ENABLED => true // Can workflows be used? Default to true
    ],
    IWorkflow::WORKFLOW_RULES => [
        IWorkflow::ON_SUBMIT => [
            IWorkflow::WITH_REVIEW => [
                IWorkflow::RULE => IWorkflow::NO_CHECKING,
                IWorkflow::MODE => IWorkflow::MODE_DEFAULT
            ],
            IWorkflow::WITHOUT_REVIEW => [
                IWorkflow::RULE => IWorkflow::NO_CHECKING,
                IWorkflow::MODE => IWorkflow::MODE_DEFAULT
            ],
        ],
        IWorkflow::END_RULES => [
            IWorkflow::UPDATE => [
                IWorkflow::RULE => IWorkflow::NO_CHECKING,
                IWorkflow::MODE => IWorkflow::MODE_DEFAULT
            ]
        ],
        IWorkflow::AUTO_APPROVE => [
            IWorkflow::RULE => IWorkflow::NEVER,
            IWorkflow::MODE => IWorkflow::MODE_DEFAULT
        ],
        IWorkflow::COUNTED_VOTES => [
            IWorkflow::RULE => IWorkflow::ANYONE,
            IWorkflow::MODE => IWorkflow::MODE_DEFAULT
        ],
        IWorkflow::GROUP_EXCLUSIONS => [
            IWorkflow::RULE => [],
            IWorkflow::MODE => IWorkflow::MODE_POLICY
        ],
        IWorkflow::USER_EXCLUSIONS => [
            IWorkflow::RULE => [],
            IWorkflow::MODE => IWorkflow::MODE_POLICY
        ]
    ],
    'router' => [
        'routes' => [
            'workflows' => [
                'type' => 'Zend\Router\Http\Segment',
                'options' => [
                    'route' => '/workflows[/]',
                    'defaults' => [
                        'controller' => IndexController::class,
                    ]
                ],
                'may_terminate' => true,
                'child_routes' => [
                    'rest_list_add' => [
                        'type' => 'Zend\Router\Http\Method',
                        'options' => [
                            'verb' => 'get'
                        ],
                    ],
                ],
            ],
        ],
    ],
    'service_manager' => [
        'aliases' => [
            IModelDAO::WORKFLOW_DAO    => WorkflowDAO::class,
            Services::WORKFLOW_MANAGER => Manager::class
        ],
        'factories' => [
            WorkflowDAO::class => InvokableServiceFactory::class,
            Manager::class     => InvokableServiceFactory::class
        ],
    ],
    'controllers' => [
        'factories' => [
            IndexController::class => IndexControllerFactory::class
        ],
    ],
    'view_manager' => [
        'template_map' => [],
        'template_path_stack'   => [
            __DIR__ . '/../view',
        ],
    ]
];
